pystagram.graph_api.endpoints.oauth package — pystagram 0.1 documentation

# pystagram.graph_api.endpoints.oauth package

## Subpackages

- pystagram.graph_api.endpoints.oauth.access_token package
  - Submodules
  - pystagram.graph_api.endpoints.oauth.access_token.access_token module
    - `AccessToken`
      - `AccessToken.get()`
  - Module contents

## Submodules

## pystagram.graph_api.endpoints.oauth.oauth module

class pystagram.graph_api.endpoints.oauth.oauth.Oauth(graph_api: GraphInstagramBaseApi)

  Bases: `object`

  The Oauth node of the Instagram Graph API.

  Parameters:

    graph_api (`InstagramGraphApi`) – An instance of the `InstagramGraphApi` class.

  property access_token

    The AccessToken node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.oauth.access_token.access_token.AccessToken` class for additional details.

## Module contents